@@ -14,7 +14,7 @@ FROM
       AND NOT REGEXP_LIKE(USERS.USERNAME, '^APEX_[0-9]{6}$')
       AND NOT REGEXP_LIKE(USERS.USERNAME, '^FLOWS_[0-9]{5}$')
 WHERE
-  REGEXP_LIKE(PROCEDURES.OWNER, '${schemas}')
+  REGEXP_LIKE(PROCEDURES.OWNER, '${schema-inclusion-rule}')
 ORDER BY
   ROUTINE_SCHEMA,
   ROUTINE_NAME
