@@ -18,7 +18,7 @@ FROM
       AND NOT REGEXP_LIKE(USERS.USERNAME, '^APEX_[0-9]{6}$')
       AND NOT REGEXP_LIKE(USERS.USERNAME, '^FLOWS_[0-9]{5}$')
 WHERE
-  REGEXP_LIKE(SEQUENCES.SEQUENCE_OWNER, '${schemas}')
+  REGEXP_LIKE(SEQUENCES.SEQUENCE_OWNER, '${schema-inclusion-rule}')
 ORDER BY
   SEQUENCE_OWNER,
   SEQUENCE_NAME
